@@ -1,4 +1,3 @@
-import datetime
 import requests
 import pandas as pd
 from requests_html import HTML
@@ -6,9 +5,10 @@ from requests_html import HTML
 class RevenueAPI(object):
 
     url = 'https://www.boxofficemojo.com/year/world/'
-    now = datetime.datetime.now()
-    year = now.year 
 
+    def __init__(self):
+        pass
+    
     def get_text_response(self):
         r = requests.get(self.url)
         if r.status_code == 200:
